@@ -8,6 +8,10 @@ from deliverable_model.serving.model.model_loaders.model_loader_base import (
 
 
 class KerasH5Model(ModelLoaderBase):
+    """
+    Keras H5 model, converter must provide `x` as input data key
+    """
+
     name = "keras_h5_model"
 
     @classmethod
